'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filterCustomClasses = exports.calendarMonthsToRender = exports.getCurrentMonthIndex = exports.calendarDayNames = exports.calendarDaysToRender = exports.lastDayOfPrevMonth = exports.daysFromPrevMonth = undefined;

var _mapObjIndexed = require('ramda/src/mapObjIndexed');

var _mapObjIndexed2 = _interopRequireDefault(_mapObjIndexed);

var _prop = require('ramda/src/prop');

var _prop2 = _interopRequireDefault(_prop);

var _pickBy = require('ramda/src/pickBy');

var _pickBy2 = _interopRequireDefault(_pickBy);

var _drop = require('ramda/src/drop');

var _drop2 = _interopRequireDefault(_drop);

var _length = require('ramda/src/length');

var _length2 = _interopRequireDefault(_length);

var _head = require('ramda/src/head');

var _head2 = _interopRequireDefault(_head);

var _findIndex = require('ramda/src/findIndex');

var _findIndex2 = _interopRequireDefault(_findIndex);

var _isEmpty = require('ramda/src/isEmpty');

var _isEmpty2 = _interopRequireDefault(_isEmpty);

var _identity = require('ramda/src/identity');

var _identity2 = _interopRequireDefault(_identity);

var _times = require('ramda/src/times');

var _times2 = _interopRequireDefault(_times);

var _map = require('ramda/src/map');

var _map2 = _interopRequireDefault(_map);

var _compose = require('ramda/src/compose');

var _compose2 = _interopRequireDefault(_compose);

var _take = require('ramda/src/take');

var _take2 = _interopRequireDefault(_take);

var _concat = require('ramda/src/concat');

var _concat2 = _interopRequireDefault(_concat);

exports.getMonths = getMonths;

var _startOfMonth = require('date-fns/startOfMonth');

var _startOfMonth2 = _interopRequireDefault(_startOfMonth);

var _endOfMonth = require('date-fns/endOfMonth');

var _endOfMonth2 = _interopRequireDefault(_endOfMonth);

var _eachDayOfInterval = require('date-fns/eachDayOfInterval');

var _eachDayOfInterval2 = _interopRequireDefault(_eachDayOfInterval);

var _lastDayOfMonth = require('date-fns/lastDayOfMonth');

var _lastDayOfMonth2 = _interopRequireDefault(_lastDayOfMonth);

var _subDays = require('date-fns/subDays');

var _subDays2 = _interopRequireDefault(_subDays);

var _getDay = require('date-fns/getDay');

var _getDay2 = _interopRequireDefault(_getDay);

var _addMonths = require('date-fns/addMonths');

var _addMonths2 = _interopRequireDefault(_addMonths);

var _subMonths = require('date-fns/subMonths');

var _subMonths2 = _interopRequireDefault(_subMonths);

var _isSameMonth = require('date-fns/isSameMonth');

var _isSameMonth2 = _interopRequireDefault(_isSameMonth);

var _differenceInCalendarMonths = require('date-fns/differenceInCalendarMonths');

var _differenceInCalendarMonths2 = _interopRequireDefault(_differenceInCalendarMonths);

var _isBefore = require('date-fns/isBefore');

var _isBefore2 = _interopRequireDefault(_isBefore);

var _isAfter = require('date-fns/isAfter');

var _isAfter2 = _interopRequireDefault(_isAfter);

var _isSameDay = require('date-fns/isSameDay');

var _isSameDay2 = _interopRequireDefault(_isSameDay);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// TODO: separate util files
// CalendarMonth utils

// return days to prepend (these days are from previous month)

/* eslint-disable import/prefer-default-export */
var daysFromPrevMonth = exports.daysFromPrevMonth = function daysFromPrevMonth(start, lastDayOfPrevMonth
// if it's first day in the month, no need to prepend days
) {
  return (0, _getDay2.default)(start) === 0 ? [] : // otherwise prepend days from previous month
  (0, _eachDayOfInterval2.default)({
    start: (0, _subDays2.default)(lastDayOfPrevMonth, (0, _getDay2.default)(start) - 1),
    end: lastDayOfPrevMonth
  });
};

var lastDayOfPrevMonth = exports.lastDayOfPrevMonth = function lastDayOfPrevMonth(month) {
  return (0, _lastDayOfMonth2.default)((0, _subMonths2.default)(month, 1));
};

// render prepended days from previous month + days from current month
var calendarDaysToRender = exports.calendarDaysToRender = function calendarDaysToRender(month) {
  // start of month
  var start = (0, _startOfMonth2.default)(month);
  // end of month
  var end = (0, _endOfMonth2.default)(month);

  // concant days from previous month and days from current month
  return (0, _concat2.default)(daysFromPrevMonth(start, lastDayOfPrevMonth(month)), (0, _eachDayOfInterval2.default)({ start: start, end: end }));
};

var calendarDayNames = exports.calendarDayNames = function calendarDayNames(months) {
  return (0, _take2.default)(7, months);
};

// TODO: separate util files
// Calendar utils

/**
 * Will return months between `firstMonth` and `lastMonth`
 * @param {Date} firstMonth
 * @param {Date} lastMonth
 * @returns {Date[]}
 */
function getMonths(firstMonth, lastMonth) {
  return (0, _compose2.default)((0, _map2.default)(function (n) {
    return (0, _addMonths2.default)((0, _startOfMonth2.default)(firstMonth), n);
  }), (0, _times2.default)(_identity2.default)
  // add one month, because differenceInCalendarMonths will return n - 1
  )((0, _differenceInCalendarMonths2.default)((0, _addMonths2.default)(lastMonth, 1), firstMonth));
}

var getCurrentMonthIndex = exports.getCurrentMonthIndex = function getCurrentMonthIndex(firstMonth, lastMonth, dates, future, visibleMonths) {
  var today = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : new Date();

  var datesOrToday = (0, _isEmpty2.default)(dates) ? [today] : dates;
  var months = getMonths(firstMonth, lastMonth);
  var index = (0, _findIndex2.default)(
  // $FlowExpected
  function (month) {
    return (0, _isSameMonth2.default)(month, (0, _head2.default)(datesOrToday));
  }, months);
  // without future and without preselect
  if (!future && (0, _isEmpty2.default)(dates)) {
    return index - (visibleMonths - 1);
  }
  // with preselect
  if (!(0, _isEmpty2.default)(dates)) {
    var toSubstract = index + visibleMonths - (0, _length2.default)(months);
    if (toSubstract >= 0) {
      return index - toSubstract;
    }
  }
  return index;
};

var calendarMonthsToRender = exports.calendarMonthsToRender = function calendarMonthsToRender(visibleMonths, currentMonth, months) {
  if (visibleMonths >= months.length) {
    return months;
  }
  return (0, _compose2.default)((0, _take2.default)(visibleMonths), (0, _drop2.default)(currentMonth))(months);
};

var filterCustomClasses = exports.filterCustomClasses = function filterCustomClasses(from, to) {
  return (0, _compose2.default)((0, _pickBy2.default)((0, _prop2.default)('length')), (0, _mapObjIndexed2.default)(function (dates) {
    return dates.filter(function (date) {
      return to ? (0, _isSameDay2.default)(date, from) || (0, _isSameDay2.default)(date, to) || (0, _isBefore2.default)(date, to) && (0, _isAfter2.default)(date, from) : (0, _isSameDay2.default)(date, from);
    });
  }));
};